pub(crate) fn value_pool_metrics(value_pool: &ValueBalance<NonNegative>)Expand description
Update value pool metrics after calculating the new chain value pool.
These metrics expose the current balances of each shielded pool and total supply for monitoring and observability purposes.
These metrics enable:
- Visualizing pool balances over time in Grafana dashboards
- Setting up alerts for anomalous conditions
- Monitoring total chain supply
The values are in zatoshis (1 ZEC = 100,000,000 zatoshis).